Package: Guerry
Type: Package
Title: Maps, Data and Methods Related to Guerry (1833) "Moral
        Statistics of France"
Version: 1.8.3
Date: 2023-10-24
Authors@R: c(
             person(given = "Michael", 
                   family = "Friendly", 
                   role=c("aut", "cre"), 
                   email="friendly@yorku.ca",
                   comment = c(ORCID = "0000-0002-3237-0941")),
             person(given = "Stephane", 
                   family = "Dray", 
                   role="aut", 
                   email="stephane.dray@univ-lyon1.fr",
                   comment = c(ORCID = "0000-0003-0153-1105")),
             person(given = "Roger", 
                   family = "Bivand", 
                   role="ctb",
                   email = "Roger.Bivand@nhh.no")
            )
Maintainer: Michael Friendly <friendly@yorku.ca>
Encoding: UTF-8
Language: en-US
Depends: R (>= 3.5.0)
Imports: sp
Suggests: knitr, sf, spdep, ade4, adegraphics, adespatial,
        RColorBrewer, corrgram, car, effects, rmarkdown, here, ggplot2,
        ggpcp, ggrepel, heplots, patchwork, candisc, colorspace,
        scales, remotes, dplyr, tidyr
Description: Maps of France in 1830, multivariate datasets from A.-M. Guerry and others, and statistical and 
	graphic methods related to Guerry's "Moral Statistics of France". The goal is to facilitate the exploration and
	development of statistical and graphic methods for multivariate data in a geospatial context of historical interest.
License: GPL
URL: https://github.com/friendly/Guerry
BugReports: https://github.com/friendly/Guerry/issues
LazyLoad: yes
LazyData: yes
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2023-10-24 16:55:48 UTC; friendly
Author: Michael Friendly [aut, cre] (<https://orcid.org/0000-0002-3237-0941>),
  Stephane Dray [aut] (<https://orcid.org/0000-0003-0153-1105>),
  Roger Bivand [ctb]
Repository: CRAN
Date/Publication: 2023-10-24 20:20:10 UTC
Built: R 4.6.0; ; 2026-04-26 19:33:30 UTC; unix
